package main

import (
	"context"
	"net/http/httptest"
	"net/url"
	"strings"
	"testing"

	"git.c3pb.de/gbe/invinoveritas/log"
	"git.c3pb.de/gbe/invinoveritas/storage"
	"git.c3pb.de/gbe/invinoveritas/storage/query"
)

type testLogger struct {
	t *testing.T
}

func (tl testLogger) Log(vals ...interface{}) error {
	tl.t.Log(vals...)
	return nil
}

func TestHandler_Index_Add(t *testing.T) {
	w := httptest.NewRecorder()

	data := make(url.Values)
	data.Set("name", "unit-test")

	r := httptest.NewRequest("POST", "/add", strings.NewReader(data.Encode()))
	r.Header.Set("Content-Type", "application/x-www-form-urlencoded")

	logger := testLogger{t}

	db, err := storage.Open(context.Background(), ":memory:", "", logger)
	if err != nil {
		t.Fatal("unexpected error:", err)
	}
	defer db.Close()

	h := Handler{
		Q: query.New(db),
	}

	hdlr := log.Request(h.index(), logger)
	hdlr.ServeHTTP(w, r)

	// We want a redirect to the index after storing something
	if w.Code != 303 {
		t.Error("unexpected HTTP status code:", w.Code)
	}
}
