-- name: AddMigration :exec
insert into migrations (name) values (@name);

-- name: CountMigrations :one
select count(*) from migrations where name = @name;

-- name: GetState :one
select val from state where key = @key;

-- name: SetState :exec
insert into state (key, val) values (@key, @val);

----
---- Session and user management
----

-- name: IsValidSession :one
select users.name
from users
join sessions using (userID)
where sessions.token = @token;

-- name: CountUsers :one
select count(*) from users;

-- name: GetAuthData :one
select userID, password from users where name = @name;

-- name: GetSalt :one
select val from state where key = 'pwsalt';

-- name: InsertSalt :exec
insert into state (key, val) values ('pwsalt', @salt);

-- name: UpdateUser :execresult
update users set password = @password where name = @name;

-- name: InsertUser :exec
insert into users (name, password) values (@name, @password);

-- name: ListUsers :many
select name from users;

-- name: DeleteUser :exec
delete from users where name = @name;

-- name: InsertSession :exec
insert into sessions (userID, token, remote, created) values (@userID, @token, @remote, @created);

-- name: DeleteSession :exec
delete from sessions where token = @token;

-- name: ListSessions :many
select users.name as name, sessions.created as created, sessions.remote as remote
from users
join sessions using (userID);

----
---- Pictures and such
----

-- name: LoadPicture :one
select picture from wines where wine_id = @wine_id;

-- name: StorePicture :exec
update wines set picture = @picture where wine_id = @wine_id;

-- name: LoadWine :one
select wine_id, name, rating, country, cast(picture is not null as bool) as has_picture
  from wines
 where wine_id = @wine_id;

-- name: ListWines :many
select wine_id, name, rating, country, cast(picture is not null as bool) as has_picture from wines;

-- name: InsertWine :execresult
insert into wines (name, rating, country) values (@name, @rating, @country);

-- name: UpdateWine :exec
update wines
set
	name = @name,
	rating = @rating,
	country = @country
where wine_id = @wine_id;

-- name: DeleteWine :exec
delete from wines where wine_id = @wine_id;

----
---- Comments
----

-- name: AddComment :exec
insert into comments (wine_id, content) values (@wine_id, @comment);

-- name: DeleteComment :exec
delete from comments where comment_id = @comment_id;

-- name: ListComments :many
select * from comments where wine_id = @wine_id;